summaryrefslogtreecommitdiffstats
path: root/target/linux/ar71xx
diff options
context:
space:
mode:
Diffstat (limited to 'target/linux/ar71xx')
-rw-r--r--target/linux/ar71xx/files/arch/mips/ath79/mach-hornet-ub.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/mach-hornet-ub.c b/target/linux/ar71xx/files/arch/mips/ath79/mach-hornet-ub.c
index d2cfb0972a..22b1e0919d 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/mach-hornet-ub.c
+++ b/target/linux/ar71xx/files/arch/mips/ath79/mach-hornet-ub.c
@@ -1,5 +1,5 @@
/*
* ALFA NETWORKS Hornet-UB board support
*
* Copyright (C) 2011-2012 Gabor Juhos <juhosg@openwrt.org>
*
@@ -133,5 +133,5 @@ static void __init hornet_ub_setup(void)
ath79_register_usb();
}
-MIPS_MACHINE(ATH79_MACH_HORNET_UB, "HORNET-UB", "ALFA NETWORKS Hornet-UB",
+MIPS_MACHINE(ATH79_MACH_HORNET_UB, "HORNET-UB", "ALFA NETWORK Hornet-UB",
hornet_ub_setup);
@@ -1,5 +1,5 @@
/*
- * ALFA NETWORKS Hornet-UB board support
+ * ALFA NETWORK Hornet-UB board support
*
* Copyright (C) 2011-2012 Gabor Juhos <juhosg@openwrt.org>